@@ -4,7 +4,9 @@ import sys
 import os
 sys.argv += ['-style', 'cleanlooks']
 sys.path.append( os.path.join(os.path.dirname(__file__), 'test') )
-runpy.run_module('test.test_view', run_name='__main__')
+sys.path.append( os.path.dirname(__file__) )
+from nose.core import main
+main(argv=['build.py', '-v', '-s', '-P', '--debug', 'test'], exit=False)
 del sys.argv[-2:]
 
 import sphinx
@@ -12,4 +14,4 @@ sphinx.main(['sphinx-build', '-a', '-E', 'doc/sphinx/source', 'doc/sphinx/build'
 
 import sys
 sys.argv += ['sdist', 'bdist_egg']
-runpy.run_module('setup', run_name='__main__')
+#runpy.run_module('setup', run_name='__main__')
