@@ -3,7 +3,7 @@ from elixir import *
 from sqlalchemy import *
 from sqlalchemy.orm import scoped_session, create_session
 
-elixir.session = scoped_session(create_session)
+elixir.session = scoped_session( create_session )
 
 import settings
 
@@ -13,4 +13,11 @@ __metadata__ = metadata
 
 __metadata__.bind = settings.ENGINE()
 __metadata__.autoflush = False
-__metadata__.transactional = False
\ No newline at end of file
+__metadata__.transactional = False
+
+from authentication import *
+from fixture import *
+from i18n import *
+from memento import *
+from synchronization import *
+from type_and_status import *
